pub struct NetworkState { /* private fields */ }Expand description
Local in-memory view of all known nodes in all joined networks.
Implementations
Sourceimpl NetworkState
impl NetworkState
pub fn new() -> Self
Sourcepub fn upsert(&mut self, info: NodeInfo)
pub fn upsert(&mut self, info: NodeInfo)
Upsert (or insert) a NodeInfo, keeping the newest announcement.
Sourcepub fn in_network<'a>(&'a self, network_id: &str) -> Vec<&'a NodeInfo>
pub fn in_network<'a>(&'a self, network_id: &str) -> Vec<&'a NodeInfo>
All nodes in a specific network.
Sourcepub fn evict_stale(&mut self, max_age_secs: u64)
pub fn evict_stale(&mut self, max_age_secs: u64)
Evict nodes whose last announcement is older than max_age_secs.